# The Gaudinski Model

#Required library
library(SoilR)

#Decomposition rates
ki=1/1.5 #Oi
ke=1/4 #Oe/a L
kh=1/35 #Oe/a H
kA1=1/3 #A, LF (>80)
kA2=1/75 #A, LF (<80)
kM=1/112 #Mineral associated
kr=1/6 #Roots
#Trasnfer coefficients from dead roots
rr=(190/(190+35+30))
rro=(35/(190+35+30))
rrm=(30/(190+35+30))
#Other parameters, inputs, and initial conditions
HFprs=c(rf1=51/(51+98+2.7), rf2=94/(94+4), rf3=1, rf4=6/(6+24), rf5=22/(22+2.4), doc=2.7/(51+98+2.7)) #rf: respiration fraction
HFini=c(FR0=390, C10=220, C20=388, C30=1366, C40=90, C50=1800, C60=560)
data(C14Atm_NH)
lambda=0.000124
calyear=C14Atm_NH[,1]
LF14=rep(150,times=length(calyear))
RI14=rep(255,times=length(calyear))

#Interpolate atmospheric 14C data at a seasonal basis
s4=data.frame(spline(C14Atm_NH,n=4*111))

#Function definition
Gaud14=function (In, RI, k1, k2, k3, k4, k5, k6, kr, rr, rro, rrm, prs, ini, rlag, C14, h,w,expermt) 
{   with(as.list(c(prs, ini)), {
    if (length(k1) == 1) 
        k1 = rep(k1, times = length(In))
    if (length(k2) == 1) 
        k2 = rep(k2, times = length(In))
    if (length(k3) == 1) 
        k3 = rep(k3, times = length(In))
    if (length(k4) == 1) 
        k4 = rep(k4, times = length(In))
    if (length(k5) == 1) 
        k5 = rep(k5, times = length(In))
    if (length(k6) == 1) 
        k6 = rep(k6, times = length(In))
    if (length(kr) == 1) 
        kr = rep(kr, times = length(In))
    if (length(rr) == 1) 
        rr = rep(rr, times = length(In))
    if (length(rro) == 1) 
        rro = rep(rro, times = length(In))
    if (length(rrm) == 1) 
        rrm = rep(rrm, times = length(In))
    FRt = NULL #Stock dead roots
    C1t = NULL #Stock pool 1
    R1t = NULL #Respiration pool 1
    C2t = NULL
    R2t = NULL
    C3t = NULL
    R3t = NULL
    C4t = NULL
    R4t = NULL
    C5t = NULL
    R5t = NULL
    C6t = NULL
    R6t = NULL
    RRt = NULL #Respiration dead roots (heterotrophic)
    RRa = (810-407-51)*h #Autotrophic root respiration (Ra)
    
    F1t = NULL
    F2t = NULL
    F3t = NULL
    F4t = NULL
    F5t = NULL
    F6t = NULL
    FFRt= NULL
    Ft = NULL
    R1Ft = NULL
    R2Ft = NULL
    R3Ft = NULL
    R4Ft = NULL
    R5Ft = NULL
    R6Ft = NULL
    RFt = NULL
    RFRt = NULL
    RhFt = NULL
    FCo = NULL
    FCm = NULL
    RFo = NULL
    RFm= NULL
    Fatm=(C14[,2]/1000)+1
    yr=C14[,1]
    RaFt = NULL
    
    for (i in 2:length(yr)) {
        FRt[1] = FR0
        C1t[1] = C10
        C2t[1] = C20
        C3t[1] = C30
        C4t[1] = C40
        C5t[1] = C50
        C6t[1] = C60
        
        FFRt[1]= kr[1]/(kr[1] + lambda)
        F1t[1] = k1[1]/(k1[1] + lambda)
        F2t[1] = k2[1]/(k2[1] + lambda)
        F3t[1] = k3[1]/(k3[1] + lambda)
        F4t[1] = k4[1]/(k4[1] + lambda)
        F5t[1] = k5[1]/(k5[1] + lambda)
        F6t[1] = k6[1]/(k6[1] + lambda)
        
        if(i==expermt) {C5t[i-1]=C5t[i-1]-C5t[i-1]*w ;C4t[i-1]=C4t[i-1]+C5t[i-1]*w}
        
        FRt[i] = FRt[i-1] + h*(RI[i] - kr[i-1]*FRt[i-1])    
        C1t[i] = C1t[i-1] + h*(In[i] - k1[i-1] * C1t[i-1])
        C2t[i] = C2t[i-1] + h*((1 - rf1 - doc) * k1[i-1] * C1t[i-1] - k2[i-1] * C2t[i-1])
        C3t[i] = C3t[i-1] + h*(rro[i-1]*kr[i-1]*FRt[i-1] + (1-rf2) * k2[i-1] * C2t[i-1] - k3[i-1] * C3t[i-1])
        C4t[i] = C4t[i-1] + h*(rrm[i-1]*kr[i-1]*FRt[i-1] + (1-rf3)*k3[i-1]*C3t[i-1] - k4[i-1]*C4t[i-1])
        C5t[i] = C5t[i-1] + h*((1-rf4)*k4[i-1]*C4t[i-1] - k5[i-1]*C5t[i-1])
        C6t[i] = C6t[i-1] + h*((1-rf5)*k5[i-1]*C5t[i-1] - k6[i-1]*C6t[i-1] + doc*k1[i-1]*C1t[i-1])
        
        RRt[i] = rr[i-1]*kr[i-1]*FRt[i-1]*h
        R1t[i] = rf1 * k1[i - 1] * C1t[i - 1]*h
        R2t[i] = rf2 * k2[i - 1] * C2t[i - 1]*h
        R3t[i] = rf3 * k3[i - 1] * C3t[i - 1]*h
        R4t[i] = rf4 * k4[i - 1] * C4t[i - 1]*h
        R5t[i] = rf5 * k5[i - 1] * C5t[i - 1]*h
        R6t[i] = k6[i - 1] * C6t[i - 1]*h
        
        FFRt[i] = ((FFRt[i-1]*FRt[i-1]) + h*(RI[i]*Fatm[i-rlag]-((kr[i-1]+lambda)*FFRt[i-1]*FRt[i-1])))/FRt[i]
        F1t[i] = ((F1t[i-1]*C1t[i-1]) + h*(In[i]*Fatm[i]-((k1[i-1]+lambda)*F1t[i-1]*C1t[i-1])))/C1t[i]
        F2t[i] = ((F2t[i-1]*C2t[i-1]) + h*((F1t[i-1]*C1t[i-1]*k1[i-1]*(1-rf1))-((k2[i-1]+lambda)*F2t[i-1]*C2t[i-1])))/C2t[i]
        F3t[i] = ((F3t[i-1]*C3t[i-1]) + h*((F2t[i-1]*C2t[i-1]*k2[i-1]*(1-rf2)) + (FFRt[i-1]*FRt[i-1]*kr[i-1]*rro[i-1]) - ((k3[i-1]+lambda)*F3t[i-1]*C3t[i-1])))/C3t[i]
        
        if(i==expermt) {F4t[i-1]=((F4t[i-1]*C4t[i-1]) + h*((C5t[i-1]*w*F5t[i-1])+(F3t[i-1]*C3t[i-1]*k3[i-1]*(1-rf3)) + (FFRt[i-1]*FRt[i-1]*kr[i-1]*rrm[i-1]) - ((k4[i-1]+lambda)*F4t[i-1]*C4t[i-1])))/C4t[i]}
        F4t[i] = ((F4t[i-1]*C4t[i-1]) + h*((F3t[i-1]*C3t[i-1]*k3[i-1]*(1-rf3)) + (FFRt[i-1]*FRt[i-1]*kr[i-1]*rrm[i-1]) - ((k4[i-1]+lambda)*F4t[i-1]*C4t[i-1])))/C4t[i]
        if(i==expermt) {F5t[i-1] = ((F5t[i-1]*C5t[i-1]) + h*((F4t[i-1]*C4t[i-1]*k4[i-1]*(1-rf4)) - ((k5[i-1]+lambda)*F5t[i-1]*C5t[i-1])-(C5t[i-1]*w*F5t[i-1])))/C5t[i]}
        F5t[i] = ((F5t[i-1]*C5t[i-1]) + h*((F4t[i-1]*C4t[i-1]*k4[i-1]*(1-rf4)) - ((k5[i-1]+lambda)*F5t[i-1]*C5t[i-1])))/C5t[i]
        F6t[i] = ((F6t[i-1]*C6t[i-1]) + h*((F5t[i-1]*C5t[i-1]*k5[i-1]*(1-rf5)) + (F1t[i-1]*doc*k1[i-1]*C1t[i-1]) -((k6[i-1]+lambda)*F6t[i-1]*C6t[i-1])))/C6t[i]
        
        RFRt[i] = FFRt[i] * RRt[i]
        R1Ft[i] = F1t[i] * R1t[i]
        R2Ft[i] = F2t[i] * R2t[i]
        R3Ft[i] = F3t[i] * R3t[i]
        R4Ft[i] = F4t[i] * R4t[i]
        R5Ft[i] = F5t[i] * R5t[i]
        R6Ft[i] = F6t[i] * R6t[i]
        RaFt[i] = Fatm[i] * RRa
        
        Ft[i] = (FFRt[i]*FRt[i] + F1t[i] * C1t[i] + F2t[i] * C2t[i] + F3t[i] * C3t[i] + F4t[i] * C4t[i] + F5t[i] * C5t[i] + F6t[i] * C6t[i])/(FRt[i] + C1t[i] + C2t[i] + C3t[i]+C4t[i] + C5t[i] + C6t[i])
        RFt[i] = (RFRt[i] + R1Ft[i] + R2Ft[i] + R3Ft[i] + R4Ft[i] + R5Ft[i] + R6Ft[i] + RaFt[i])/(RRt[i] + R1t[i] + R2t[i] + R3t[i] + R4t[i] + R5t[i] + R6t[i] + RRa)
        RhFt[i] = (RFRt[i] +R1Ft[i] + R2Ft[i] + R3Ft[i] + R4Ft[i] + R5Ft[i] + R6Ft[i])/(RRt[i] +R1t[i] + R2t[i] + R3t[i] + R4t[i] + R5t[i] + R6t[i])
        FCo[i] = (F1t[i] * C1t[i] + F2t[i] * C2t[i] + F3t[i] * C3t[i])/(C1t[i] + C2t[i] + C3t[i])
        FCm[i] = (F4t[i] * C4t[i] + F5t[i] * C5t[i] + F6t[i] * C6t[i])/(C4t[i] + C5t[i] + C6t[i])
        RFo[i] = (R1Ft[i] + R2Ft[i] + R3Ft[i])/(R1t[i] + R2t[i] + R3t[i])
        RFm[i] = (R4Ft[i] + R5Ft[i] + R6Ft[i])/(R4t[i] + R5t[i] + R6t[i])

    }
    return(list(year=yr, C4t=C4t, C5t=C5t, C6t=C6t, F4t=F4t, F5t=F5t, FRt=FRt, RRt=RRt, Co = C1t + C2t + C3t,RRa=RRa, Ro = R1t + R2t + R3t, Cm=C4t+C5t+C6t, Rm=R4t+R5t+R6t,
                Del14C =(Ft-1)*1000, R14C = (RFt-1)*1000,FFRt=FFRt, Co14=(FCo-1)*1000, Cm14=(FCm-1)*1000, R14o=(RFo-1)*1000, R14m=(RFm-1)*1000,Rh14=(RhFt-1)*1000))
    })
}

