#################################################################################
####                R code for reproducing results in                       #####
# Predicting decadal trends and transient responses of radiocarbon storage      #
#                  and fluxes in a temperate forest soil                        #
#################################################################################
# Submited to Biogeosciences, May 2012. 
# Authors: CA Sierra, SE Trumbore, EA Davidson, SD Frey, KE Savage, FM Hopkins
#################################################################################

# 1. Set working directoy, import datasets, and create data objects

setwd("/Users/_csierra/Documents/Submissions/2012/HarvardForest/Data/") # Change to directory where the data are stored

#Radiocarbon data in respired CO2 from incubations
org1y=read.csv("Org1year.csv")
min1y=read.csv("Min1year.csv")
org3y=read.csv("Org3year.csv")
min3y=read.csv("Min3year.csv")
min5y=read.csv("Min5year.csv")
org5y=read.csv("Org5year.csv")

orgmean=rbind(tapply(org1y[,2],org1y[,1],mean),tapply(org3y[,2],org3y[,1],mean),tapply(org5y[,2],org5y[,1],mean))
minmean=rbind(tapply(min1y[,2],min1y[,1],mean),tapply(min3y[,2],min3y[,1],mean),tapply(min5y[,2],min5y[,1],mean))
orgsd=rbind(tapply(org1y[,2],org1y[,1],sd),tapply(org3y[,2],org3y[,1],sd),tapply(org5y[,2],org5y[,1],sd))
minsd=rbind(tapply(min1y[,2],min1y[,1],sd),tapply(min3y[,2],min3y[,1],sd),tapply(min5y[,2],min5y[,1],sd))

#Radiocarbon data from respired CO2 in field traps

Er=read.csv("Traps.csv")
Erm=aggregate(c14~Treat+Date,mean,data=Er)
Ersd=aggregate(c14~Treat+Date,sd,data=Er)
Cm=Erm[Erm$Treat=="Control",]
Wm=Erm[Erm$Treat=="Heated",]
Nm=Erm[Erm$Treat=="Nitrogen",]
WNm=Erm[Erm$Treat=="Nitrogen+Heated",]
Am=Erm[Erm$Treat=="Air",]
Csd=Ersd[Ersd$Treat=="Control",]
Wsd=Ersd[Ersd$Treat=="Heated",]
Nsd=Ersd[Ersd$Treat=="Nitrogen",]
WNsd=Ersd[Ersd$Treat=="Nitrogen+Heated",]

#Radiocarbon in total soil CO2 efflux
resp14=read.csv("HF14C.csv")

#Radiocarbon in the control plots by layer
layersC=read.csv("LayersControl.csv")


################################################################################
# 2. Calculations
# Multiple comparisons
library(multcomp)

mdM=lm(c14~Treat,min5y)
mdO=lm(c14~Treat,org5y)

mdM1=aov(c14~Treat,min1y)
mdMcomp1<- glht(mdM1, linfct = mcp(Treat = "Dunnett"))
mdM3=aov(c14~Treat,min3y)
mdMcomp3<- glht(mdM3, linfct = mcp(Treat = "Dunnett"))
mdM5=aov(c14~Treat,min5y)
mdMcomp5<- glht(mdM5, linfct = mcp(Treat = "Dunnett"))

#Summary statistics of multiple comparison tests with F and p-values
mdMcomp1
mdMcomp3
mdMcomp5

################################################################################
# 3. Simulations

#Source code of Gaudinski model provided in a separate file
source("GaudinskiModel.R")
psi=1:6
k=1/c(110,75,35,4,3,1.5) #Decomposition rates in Gaudinski's model
rho=c(560,1800,1370,90,390,220) #Pool sizes in Gaudinski's model

#Run simulations in for the control treatment and the three hypotheses
ctrl=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=ki,k2=ke,k3=kh,k4=kA1,k5=kA2,k6=kM, kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0, C14=s4, h=1/4,w=1,expermt=1000)

#H0 is actually Hypothesis 1 in the manuscript
a=1.5
H0=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=c(rep(ki,times=426),rep(ki*a,times=20)),k2=c(rep(ke,times=426),rep(ke*a,times=20)),k3=c(rep(kh,times=426),rep(kh*a,times=20)),k4=c(rep(kA1,times=426),rep(kA1*a,times=20)),k5=c(rep(kA2,times=426),rep(kA2*a,times=20)),k6=c(rep(kM,times=426),rep(kM*a,times=20)), kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0,C14=s4, h=1/4,w=1,expermt=1000)

#H1 is actually Hypothesis 2 in the manuscript
kH1=k*(-0.2*psi+2.2)
H1=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=c(rep(ki,times=426),rep(kH1[6],times=20)),k2=c(rep(ke,times=426),rep(kH1[4],times=20)),k3=c(rep(kh,times=426),rep(kH1[3],times=20)),k4=c(rep(kA1,times=426),rep(kH1[5],times=20)),k5=c(rep(kA2,times=426),rep(kH1[2],times=20)),k6=c(rep(kM,times=424),rep(kH1[1],times=20)), kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0,C14=s4, h=1/4,w=1,expermt=1000)

#H2 is the simulation in which 8% of the carbon from the intermediate pool is transfered to the labile pool
H2=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=ki,k2=ke,k3=kh,k4=kA1,k5=kA2,k6=kM, kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0, C14=s4, h=1/4,w=0.08,expermt=427)

#H3 is hypothesis 3 in the manuscript
a=1.5
H3=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=c(rep(ki,times=426),rep(ki*a,times=20)),k2=c(rep(ke,times=426),rep(ke*a,times=20)),k3=kh,k4=c(rep(kA1,times=426),rep(kA1*a,times=20)),k5=kA2,k6=kM, kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0,C14=s4, h=1/4,w=1,expermt=1000)

# Model test by horizon. Stella results by S. Trumbore
years=1991:2010
Oi14C=c(157.38,147.79,139.93,131.98,125.33,119.11,113.04,106.35,103.45,98.48,92.83,85.61,81.2,74.4,69.47,63.82,57.94,52.65,47.55,41.85)
OhumOLF=c(205.9851573,203.5954219,201.0425923,198.4163822,195.688141,192.9310394,190.1407523,187.3041086,184.3747664,181.5706944,178.724981,
            175.7934955,172.6833593,169.5814841,166.3264379,163.0476363,159.6953714,156.2641635,152.789395,149.2754886)
Amin14C=c(37.59,38.42,39.2,39.95,40.68,41.37,42.03,42.65,43.27,43.86,44.41,44.93,45.42,45.88,46.31,46.7,47.07,47.41,47.72,47.99)
ALFAhum=c(117.7214286,118.8980952,119.9109524,120.7633333,121.4733333,122.042381,122.4895238,122.822381,123.0452381,123.1790476,123.2152381,
            123.1671429,123.0242857,122.8033333,122.5033333,122.12,121.6685714,121.137619,120.5366667,119.8666667)
y=c(1996,2007)
Amin=c(67.5,69); Oi=c(132.4,63.7); Oea=c(199,140); ALF=c(174,118.5)
Aminsd=c(36.06,48.08); Oisd=c(11.32,7.21); Oeasd=c(48.08,10.02); ALFsd=c(50.91,75.66)

Rt=c(1999,2006.7,2008.7,2008.5)
Rh14o=c(123.8672784,110.9378881,104.3017664,60.47085753)    #Observed radiocarbon in heterotrophic respiration
Rh14m=c(201.79,192.43,183.57,175.15,167.24,159.83,152.84,146.12,140.09,134.45,128.96,123.38,118.03,112.64,107.39,102.21,97.04,91.94,86.94,NA)

######
#Processes simulation output
H0diffo=c(H0$R14o[430],H0$R14o[438],H0$R14o[444])-c(ctrl$R14o[430],ctrl$R14o[438],ctrl$R14o[444])
H0diffm=c(H0$R14m[430],H0$R14m[438],H0$R14m[444])-c(ctrl$R14m[430],ctrl$R14m[438],ctrl$R14m[444])
H1diffo=c(H1$R14o[430],H1$R14o[438],H1$R14o[444])-c(ctrl$R14o[430],ctrl$R14o[438],ctrl$R14o[444])
H1diffm=c(H1$R14m[430],H1$R14m[438],H1$R14m[444])-c(ctrl$R14m[430],ctrl$R14m[438],ctrl$R14m[444])
H2diffo=c(H2$R14o[430],H2$R14o[438],H2$R14o[444])-c(ctrl$R14o[430],ctrl$R14o[438],ctrl$R14o[444])
H2diffm=c(H2$R14m[430],H2$R14m[438],H2$R14m[444])-c(ctrl$R14m[430],ctrl$R14m[438],ctrl$R14m[444])
H3diffo=c(H3$R14o[430],H3$R14o[438],H3$R14o[444])-c(ctrl$R14o[430],ctrl$R14o[438],ctrl$R14o[444])
H3diffm=c(H3$R14m[430],H3$R14m[438],H3$R14m[444])-c(ctrl$R14m[430],ctrl$R14m[438],ctrl$R14m[444])

orgbars=sqrt((orgsd[,1]^2)+(orgsd[,2]^2))
minbars=sqrt((minsd[,1]^2)+(minsd[,2]^2))

sampdate=c(2006,2008,2010)

#Differences between the model predictions and radiocarbon in control plots
modorg=do.call(cbind,approx(ctrl$year,ctrl$R14o,layersC[1:12,1]))
resorg=layersC[1:12,2]-modorg[,2]

modmin=do.call(cbind,approx(ctrl$year,ctrl$R14o,layersC[13:25,1]))
resmin=layersC[13:25,2]-modmin[,2]

################################################################################
# 4. Figures

#Figure 2
par(mar=c(4,4.5,1,2))
plot(s4, type="l",xlim=c(1950,2010),ylab=expression(paste(Delta^14,"C ","(\u2030)")),xlab="Year", ylim=c(-20,1000))
lines(ctrl$year, ctrl$R14C,col=2,lwd=2)
points(resp14[1:11,1],resp14[1:11,2],pch=19,cex=0.5)
points(resp14[12:173,1],resp14[12:173,2],pch=19,col=2,cex=0.5)
points(resp14[158,1],resp14[158,2],pch=19,cex=0.5)
legend("topleft",c("Atmosphere", "Empirical model","Observations"), lty=c(1,1,0),col=c(1,2,2),pch=c(NA,NA,19),bty="n")

par(fig=c(0.45,0.95,0.45,0.95),new=TRUE)
plot(s4, type="l",xlim=c(1995,2010),ylab=expression(paste(Delta^14,"C ","(\u2030)")),xlab="Year", ylim=c(-20,200))
lines(ctrl$year, ctrl$R14C,col=2,lwd=2)
points(resp14[1:11,1],resp14[1:11,2],pch=19,cex=0.5)
points(resp14[12:173,1],resp14[12:173,2],pch=19,col=2,cex=0.5)
points(resp14[158,1],resp14[158,2],pch=19,cex=0.5)
par(fig=c(0,1,0,1),new=FALSE)

library(colorspace)
pal=rainbow_hcl(4,start=60,end=240)
# Figure 3
par(mar=c(5,4.5,4,2))
plot(years,Oi14C,type="l",ylim=c(0,300),xlab="Year",ylab=expression(paste(Delta^14,"C (\u2030)")))
lines(years, OhumOLF,col=pal[1])
lines(years,Amin14C,col=pal[2])
lines(years, ALFAhum,col=pal[3])
points(y,Oi,pch=19)
arrows(y,Oi-Oisd,y,Oi+Oisd,angle=90, code=3,length=0.1)
points(y+0.1,Oea,col=pal[1],pch=15)
arrows(y+0.1,Oea-Oeasd,y+0.1,Oea+Oeasd,angle=90, code=3,length=0.1,col=pal[1])
points(y+0.3,Amin,col=pal[2],pch=17)
arrows(y+0.3,Amin-Aminsd,y+0.3,Amin+Aminsd,angle=90, code=3,length=0.1,col=pal[2])
points(y+0.5,ALF,col=pal[3],pch=18)
arrows(y+0.5,ALF-ALFsd,y+0.5,ALF+ALFsd,angle=90, code=3,length=0.1,col=pal[3])
legend("topright",c("Oi","Oe/a","A-LF","Min Assoc."),bty="n",lty=c(1,1,1,1),pch=c(19,15,17,18),col=c(1,pal[1],pal[2],pal[3]))

#Figure 4
plot(as.Date(Cm$Date),Cm$c14,ylim=c(0,250),xlab="Years",ylab=expression(paste(Delta^14,"C (\u2030)")),pch=20)
points(as.Date(Wm$Date),Wm$c14,col=pal[1],pch=15,cex=0.8)
points(as.Date(Nm$Date),Nm$c14,col=pal[2],pch=17,cex=0.8)
points(as.Date(WNm$Date),WNm$c14,col=pal[4],pch=18)
points(as.Date(Am$Date),Am$c14,pch=19,col=pal[3],cex=0.8)
arrows(as.Date(Cm$Date),Cm$c14-Csd$c14,as.Date(Cm$Date),Cm$c14+Csd$c14,code=3,angle=90,length=0.05,pch=20)
arrows(as.Date(Wm$Date),Wm$c14-Wsd$c14,as.Date(Wm$Date),Wm$c14+Wsd$c14,code=3,angle=90,col=pal[1],length=0.05,pch=20)
arrows(as.Date(Nm$Date),Nm$c14-Nsd$c14,as.Date(Nm$Date),Nm$c14+Nsd$c14,code=3,angle=90,col=pal[2],length=0.05,pch=20)
arrows(as.Date(WNm$Date),WNm$c14-WNsd$c14,as.Date(WNm$Date),WNm$c14+WNsd$c14,code=3,angle=90,col=pal[4],length=0.05,pch=20)
legend("topright",c("Control","Warming","Nitrogen","Nitrogen+Warming","Air"),bty="n",pch=c(20,15,17,18,19),col=c(1,pal[1],pal[2],pal[4],pal[3]))

#Figure 5
#First year
par(mfrow=c(3,2),mar=c(4,4,2,1))
boxplot(c14~Treat,data=org1y,ylab=expression(paste(Delta^14,"C (\u2030)")),xlab="Treatment",main="a",cex.main=0.9, font.main=1,ylim=c(60,180),names=c("Control","Warming","Nitrogen","W+N"))
boxplot(c14~Treat,data=min1y,ylab=expression(paste(Delta^14,"C (\u2030)")),xlab="Treatment",main="b",cex.main=0.9, font.main=1,ylim=c(60,180),names=c("Control","Warming","Nitrogen","W+N"),border=c(1,2,2,2))

#Third year
boxplot(c14~Treat,data=org3y,ylab=expression(paste(Delta^14,"C (\u2030)")),xlab="Treatment",main="c",cex.main=0.9, font.main=1,ylim=c(60,180),names=c("Control","Warming","Nitrogen","W+N"))
boxplot(c14~Treat,data=min3y,ylab=expression(paste(Delta^14,"C (\u2030)")),xlab="Treatment",main="d",cex.main=0.9, font.main=1,ylim=c(60,180),names=c("Control","Warming","Nitrogen","W+N"))

#Fifth year
boxplot(c14~Treat,data=org5y,ylab=expression(paste(Delta^14,"C (\u2030)")),xlab="Treatment",main="e",cex.main=0.9, font.main=1,ylim=c(60,180),names=c("Control","Warming","Nitrogen","W+N"))
boxplot(c14~Treat,data=min5y,ylab=expression(paste(Delta^14,"C (\u2030)")),xlab="Treatment",main="f",cex.main=0.9, font.main=1,ylim=c(60,180),names=c("Control","Warming","Nitrogen","W+N"),border=c(1,1,2,2))
par(mfrow=c(1,1))

#Figure 6
par(mfrow=c(2,1))
plot(psi,k,xlab="",ylab="k (1/yr)",frame.plot=F,ylim=c(0,1),col=c(1,"gray",1,"gray",1,"gray"),pch=19)
barplot(rho/sum(rho),axis.lty=1,space=c(0,0),names.arg=1:6,xlab="Decomposability rank", ylab="Relative amount of carbon in pool",col=c(1,"gray",1,"gray",1,"gray"))
par(mfrow=c(1,1))

#Figure 7
par(mfrow=c(2,1),mar=c(4,4,1,1))
plot(psi,-0.12*psi+1.92,ylim=c(0.5,2),type="l",xlab="",ylab=expression(paste(k[2]/k[1])),col=4)
lines(psi,k*1.5/k,col=2)
abline(h=1,lty=2)
lines(psi,c(1,1,1,1.5,1.5,1.5),type="s",col="forestgreen",lty=2,lwd=2)

plot(psi,k*(-0.12*psi+1.92),ylim=c(0,1),xlab="Decomposability index",ylab="k",col=4,type="l")
lines(psi,k*1.5,col=2)
lines(psi,k)
lines(psi,c(k[1:3],k[4:6]*1.5),col="forestgreen",lty=2,lwd=2)
legend("topleft",c("Control", "H1", "H2","H3"), col=c(1,2,4,"forestgreen"),lty=c(1,1,1,2), bty="n")
par(mfrow=c(1,1))

#Figure 8
par(mfrow=c(2,1),mar=c(4,4,1,1))
plot(sampdate,H1diffo,type="b",ylim=c(-30,50),xlab="Sampling year",ylab="Treatment Effect (\u2030)",col=4,pch=15)
lines(sampdate,H0diffo,type="b",col=2,pch=17)
lines(sampdate,H3diffo,type="b",col="forestgreen",pch=18)
lines(sampdate,orgmean[,2]-orgmean[,1],type="b",pch=19)
arrows(sampdate,(orgmean[,2]-orgmean[,1])+(orgbars),sampdate,(orgmean[,2]-orgmean[,1])-(orgbars),angle=90, code=3,length=0.1)
arrows(sampdate,H1diffo-(sd(resorg)),sampdate,H1diffo+(sd(resorg)),angle=90, code=3,length=0.1,col=4)
arrows(sampdate,H0diffo-(sd(resorg)),sampdate,H0diffo+(sd(resorg)),angle=90, code=3,length=0.1,col=2)
arrows(sampdate,H3diffo-(sd(resorg)),sampdate,H3diffo+(sd(resorg)),angle=90, code=3,length=0.1,col="forestgreen")
legend(2006.5,50,c("H1","H2","H3","Observations"),lty=c(1,1,1,1),col=c(2,4,"forestgreen",1),pch=c(15,17,18,19),bty="n")
abline(h=0,lty=2)

plot(sampdate,H1diffm,type="b",ylim=c(-30,50),xlab="Sampling year",ylab="Treatment Effect (\u2030)",col=4,pch=15)
lines(sampdate,H0diffm,type="b",col=2,pch=17)
lines(sampdate,H3diffm,type="b",col="forestgreen",pch=18)
lines(sampdate,minmean[,2]-minmean[,1],type="b",pch=19)
arrows(sampdate,(minmean[,2]-minmean[,1])+(minbars),sampdate,(minmean[,2]-minmean[,1])-(minbars),angle=90, code=3,length=0.1)
arrows(sampdate,H1diffm-(sd(resmin)),sampdate,H1diffm+(sd(resmin)),angle=90, code=3,length=0.1,col=4)
arrows(sampdate,H0diffm-(sd(resmin)),sampdate,H0diffm+(sd(resmin)),angle=90, code=3,length=0.1,col=2)
arrows(sampdate,H3diffm-(sd(resmin)),sampdate,H3diffm+(sd(resmin)),angle=90, code=3,length=0.1,col="forestgreen")
abline(h=0,lty=2)
par(mfrow=c(1,1))

################################################################################
#GLUE Analysis

Obsdif=minmean[1,2]-minmean[1,1] #Observed difference (treatment effect)
Modbase=ctrl$R14m[430]

Glue=function(n){
  ka4=NULL
  ka5=NULL
  ka6=NULL
  Moddif=NULL
  for(i in 1:n) {
    ka4[i]=runif(1,0,5)*kA1
    ka5[i]=runif(1,0,5)*kA2
    ka6[i]=runif(1,0,5)*kM
    Rnd=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=ki,k2=ke,k3=kh,k4=c(rep(kA1,times=426),
                                                                                                     rep(ka4[i],times=20)),k5=c(rep(kA2,times=426),rep(ka5[i],times=20)),k6=c(rep(kM,times=426),rep(ka6[i],times=20)), 
               kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0, C14=s4, h=1/4,w=1,expermt=1000)
    Moddif[i]=Rnd$R14m[430]-Modbase
  }
  return(data.frame(ka4,ka5,ka6,Moddif))
}

n=500
test=Glue(n) #This make take some time to run

#The likelihood measure
LM=function(M,Omin,Omean,Omax){
  if(M<=Omean){
    tmp=(M-Omin)/(Omean-Omin)
  }
  if(M > Omean){
    tmp=(Omax-M)/(Omax-Omin)
  }
  return(tmp)
}

Like=NULL
for(i in 1:n){
  Like[i]=LM(test$Moddif[i],Omin=H2diffm[1]-sd(resmin)[1],Omean=H2diffm[1],Omax=H2diffm[1]+sd(resmin)[1])
}

#Figure 9
par(mfrow=c(3,2))
plot(test$ka4,test$Moddif,pch=20,col=4,xlab="k low density fraction",ylab="Difference with control")
abline(v=kA1)
abline(h=0,lty=2)

plot(test$ka4,Like,pch=20,col=4,xlab="k low density fraction",ylab="Likelihood measure")
abline(v=kA1)
abline(h=0,lty=2)

plot(test$ka5,test$Moddif,pch=20,col=4,xlab="k intermediate density fraction",ylab="Difference with control")
abline(v=kA2)
abline(h=0,lty=2)

plot(test$ka5,Like,pch=20,col=4,xlab="k intermediate density fraction",ylab="Likelihood measure")
abline(v=kA2)
abline(h=0,lty=2)

plot(test$ka6,test$Moddif,pch=20,col=4,xlab="k high density fraction",ylab="Difference with control")
abline(v=kM)
abline(h=0,lty=2)

plot(test$ka6,Like,pch=20,col=4,xlab="k high density fraction",ylab="Likelihood measure")
abline(v=kM)
abline(h=0,lty=2)
par(mfrow=c(1,1))

###############
# GLUE part 2, including a parameter to transfer carbon from the intermediate to the fast cycling pool

Glue2=function(n){
  ka4=NULL
  ka5=NULL
  ka6=NULL
  w=NULL
  Moddif=NULL
  for(i in 1:n) {
    ka4[i]=runif(1,0,5)*kA1
    ka5[i]=runif(1,0,5)*kA2
    ka6[i]=runif(1,0,5)*kM
    w[i]=runif(1,0,0.1)
    Rnd=Gaud14(In=rep(LF14,times=dim(s4)[1]),RI=rep(RI14[1],times=dim(s4)[1]),k1=ki,k2=ke,k3=kh,k4=c(rep(kA1,times=426),
                                                                                                     rep(ka4[i],times=20)),k5=c(rep(kA2,times=426),rep(ka5[i],times=20)),k6=c(rep(kM,times=426),rep(ka6[i],times=20)), 
               kr=kr, rr=rr,rro=rro,rrm=rrm,prs=HFprs,ini=HFini,rlag = 0, C14=s4, h=1/4,w=w[i],expermt=427)
    Moddif[i]=Rnd$R14m[430]-Modbase
  }
  return(data.frame(ka4,ka5,ka6,w,Moddif))
}

test2=Glue2(n) #This make take some time to run

Like2=NULL
for(i in 1:n){
  Like2[i]=LM(test2$Moddif[i],Omin=H2diffm[1]-sd(resmin)[1],Omean=H2diffm[1],Omax=H2diffm[1]+sd(resmin)[1])
}

#Figure 10
par(mfrow=c(4,2))
plot(test2$ka4,test2$Moddif,pch=20,col=4,xlab="k low density fraction",ylab="Difference with control")
abline(v=kA1)
abline(h=0,lty=2)

plot(test2$ka4,Like2,pch=20,col=4,xlab="k low density fraction",ylab="Likelihood measure")
abline(v=kA1)
abline(h=0,lty=2)

plot(test2$ka5,test2$Moddif,pch=20,col=4,xlab="k intermediate density fraction",ylab="Difference with control")
abline(v=kA2)
abline(h=0,lty=2)

plot(test2$ka5,Like2,pch=20,col=4,xlab="k intermediate density fraction",ylab="Likelihood measure")
abline(v=kA2)
abline(h=0,lty=2)

plot(test2$ka6,test2$Moddif,pch=20,col=4,xlab="k high density fraction",ylab="Difference with control")
abline(v=kM)
abline(h=0,lty=2)

plot(test2$ka6,Like2,pch=20,col=4,xlab="k high density fraction",ylab="Likelihood measure")
abline(v=kM)
abline(h=0,lty=2)

plot(test2$w,test2$Moddif,pch=20,col=4,xlab="Fraction transferred from intermediate to labile pool",ylab="Difference with control")
abline(v=0)
abline(h=0,lty=2)

plot(test2$w,Like2,pch=20,col=4,xlab="Fraction transferred from intermediate to labile pool",ylab="Likelihood measure")
abline(v=0)
abline(h=0,lty=2)
par(mfrow=c(1,1))
